@@ -23,13 +23,14 @@ package IPC::PrettyPipe;
 
 ## no critic (RequireUseStrict)
 
-our $VERSION = '0.03_03';
+our $VERSION = '0.01';
 
 use Carp;
 
 use List::Util qw[ sum ];
 use Module::Load qw[ load ];
-use Module::Runtime qw[ check_module_name compose_module_name use_package_optimistically ];
+use Module::Path qw[ module_path ];
+use Module::Runtime 'compose_module_name';
 use Safe::Isa;
 use Try::Tiny;
 
@@ -320,27 +321,27 @@ sub stream {
 
     my $self = shift;
 
-    my $spec = shift;
+    my $op = shift;
 
-    if ( $spec->$_isa( 'IPC::PrettyPipe::Stream' ) ) {
+    if ( $op->$_isa( 'IPC::PrettyPipe::Stream' ) ) {
 
         croak( "too many arguments\n" )
           if @_;
 
-        $self->streams->push( $spec );
+        $self->streams->push( $op );
 
     }
 
-    elsif ( !ref $spec ) {
+    elsif ( !ref $op ) {
 
         $self->streams->push(
-          IPC::PrettyPipe::Stream->new( spec => $spec, +@_ ? ( file => @_ ) : () )
+          IPC::PrettyPipe::Stream->new( op => $op, +@_ ? ( file => @_ ) : () )
 			     );
     }
 
     else {
 
-        croak( "illegal stream specification\n" );
+        croak( "illegal stream operator\n" );
 
     }
 
@@ -408,25 +409,10 @@ sub _backend_factory {
 
     my ( $self, $type, $req ) = ( shift, shift, shift );
 
-    check_module_name( $req );
+    my $module = compose_module_name( "IPC::PrettyPipe::$type", $req );
 
-    my $role = compose_module_name( __PACKAGE__,
-				    { Render => 'Renderer',
-				      Execute => 'Executor'}->{$type} );
-
-    my $module;
-
-    for my $try (  $req,
-		   compose_module_name( "IPC::PrettyPipe::$type", $req ) ) {
-
-	next unless use_package_optimistically($try)->DOES( $role );
-
-	$module = $try;
-	last;
-    }
-
-    croak( "requested $type module ($req) either doesn't exist or doesn't consume $role\n" )
-      if ! defined $module;
+    croak( "unknown $type ($req => $module)\n" )
+      unless defined module_path( $module );
 
     load $module;
 
@@ -505,7 +491,7 @@ B<L<IPC::PrettyPipe::DSL>>.
 
 B<L<IPC::PrettyPipe>> doesn't render a pipeline directly; instead it
 passes that job on to another object (which must consume the
-B<L<IPC::PrettyPipe::Renderer>> role).
+B<L<IPC::PrettyPipe::Render>> role).
 
 By default B<IPC::PrettyPipe> provides a renderer which uses
 B<L<Template::Tiny>> to render a pipeline as if it were to be fed to a
@@ -518,7 +504,7 @@ replaced via the B<L</renderer>> attribute.
 
 Just as with rendering, B<IPC::PrettyPipe> doesn't execute a pipeline
 on its own.  Instead it calls upon another object (which must consume
-the B<L<IPC::PrettyPipe::Executor>> role).  By default it provides an
+the B<L<IPC::PrettyPipe::Execute>> role).  By default it provides an
 executor which uses B<L<IPC::Run>> to run the pipeline.  The executor
 may be replaced via the B<L</executor>> attribute.
 
@@ -550,13 +536,13 @@ Create a new C<IPC::PrettyPipe> object. The available attributes are:
 
 =over
 
-=item C<cmds>
+=item cmds
 
 I<Optional>. The value should be an arrayref of commands to load into
 the pipe.  The contents of the array are passed to the B<L</ffadd>>
 method for processing.
 
-=item C<argpfx>, C<argsep>
+=item argpfx, argsep
 
 I<Optional>.  The default prefix and separation attributes for
 arguments to commands.  See B<L<IPC::PrettyPipe::Arg>> for more
@@ -568,14 +554,14 @@ I<Optional>. An B<L<IPC::PrettyPipe::Arg::Format>> object specifying
 the default prefix and separation attributes for arguments to
 commands.  May be overridden by C<L</argpfx>> and C<L</argsep>>.
 
-=item C<executor>
+=item executor
 
 I<Optional>. The means by which the pipeline will be executed.  It may
 be either a class name or an object reference, and must consume the
 B<L<IPC::PrettyPipe::Executor>> role.  It defaults to
 C<L<IPC::PrettyPipe::Execute::IPC::Run>>.
 
-=item C<renderer>
+=item renderer
 
 I<Optional>. The means by which the pipeline will be rendered.  It may
 be either a class name or an object reference, and must consume the
@@ -618,7 +604,7 @@ A command name (i.e. a string), for a command without arguments.
 =item *
 
 A string which matches a stream specification
-(L<IPC::PrettyPipe::Stream::Utils/Stream Specification>), which will cause
+(L<IPC::PrettyPipe::Stream::Util/Stream Specification>), which will cause
 a new I/O stream to be attached to the pipeline.  If the specification
 requires an additional parameter, the next value in C<@cmds> will be
 used for that parameter.
@@ -648,13 +634,6 @@ arguments; it does not affect existing arguments.
 
 See B<L<IPC::PrettyPipe::Arg>> for more information.
 
-=item B<cmds>
-
-  $cmds = $pipe->cmds;
-
-Return a B<L<IPC::PrettyPipe::Queue>> object containing the
-B<L<IPC::PrettyPipe::Cmd>> objects associated with the pipe.
-
 =item B<render>
 
   my $string = $pipe->render
@@ -674,15 +653,15 @@ Execute the pipeline.
   $pipe->stream( $stream_spec, $file );
 
 Add an I/O stream to the pipeline.  See
-L<IPC::PrettyPipe::Stream::Utils/Stream Specification> for more
+L<IPC::PrettyPipe::Stream::Util/Stream Specification> for more
 information.
 
 =item B<streams>
 
   $streams = $pipe->streams
 
-Return a B<L<IPC::PrettyPipe::Queue>> object containing the
-B<L<IPC::PrettyPipe::Stream>> objects associated with the pipe.
+Return the streams associated with the command as an arrayref of
+B<L<IPC::PrettyPipe::Stream>> objects.
 
 =item B<valmatch>
 
@@ -704,11 +683,11 @@ are avaliable:
 
 =over
 
-=item C<firstvalue>
+=item firstvalue
 
 The first matched argument will be replaced with this value
 
-=item C<lastvalue>
+=item lastvalue
 
 The last matched argument will be replaced with this value.
 
