@@ -24,8 +24,6 @@ package IPC::PrettyPipe::Arg;
 use Carp;
 
 use Moo;
-use String::ShellQuote;
-
 use Types::Standard qw[ Str ];
 
 has name => (
@@ -84,11 +82,6 @@ sub BUILDARGS {
     return {@_};
 }
 
-sub quoted_name {  shell_quote( $_[0]->name )  }
-
-sub quoted_value {  shell_quote( $_[0]->value )  }
-
-
 # for render templates
 sub has_blank_value {
 
@@ -156,7 +149,7 @@ __END__
 
 =head1 NAME
 
-B<IPC::PrettyPipe::Arg> - An argument to an B<IPC::PrettyPipe::Cmd> command
+B<IPC::PrettyPipe::Arg> - An argument to an B<L<IPC::PrettyPipe::Cmd>> command
 
 =head1 SYNOPSIS
 
@@ -239,38 +232,6 @@ Get or set the value of the C<pfx> attribute.
 
 Get or set the value of the C<sep> attribute.
 
-=item B<name>
-
-  $name = $self->name;
-
-The argument's name;
-
-=item B<quoted_name>
-
-  $name = $self->quoted_name;
-
-The argument's name, appropriately quoted for passing as a
-single word to a Bourne compatible shell.
-
-=item B<value>
-
-  $value = $self->value;
-
-The argument's value;
-
-=item B<quoted_value>
-
-  $value = $self->quoted_value;
-
-The argument's value, appropriately quoted for passing as a
-single word to a Bourne compatible shell.
-
-=item B<has_value>
-
-  $bool = $self->has_value
-
-Returns true if the argument has been assigned a value.
-
 =item B<has_blank_value>
 
   $bool = $self->has_blank_value
@@ -309,7 +270,7 @@ If the argument has a value, perform the equivalent to
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2014 Smithsonian Astrophysical Observatory
+Copyright 2013 Smithsonian Astrophysical Observatory
 
 This software is released under the GNU General Public License.  You
 may find a copy at
