@@ -40,8 +40,6 @@ has elements => (
 
 sub empty { ! !!@{ $_[0]->elements } }
 
-sub nelements { scalar @{ $_[0]->elements } }
-
 sub push {
 
     my ( $self, $elem ) = ( shift, shift );
@@ -126,18 +124,12 @@ Returns true if there are no elements in the queue.
 
 Returns an arrayref containing the queue's elements.
 
-=item nelements
-
-  $nelements = $q->nelements;
-
-Returns the number of elements in the queue.
-
 =back
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2014 Smithsonian Astrophysical Observatory
+Copyright 2013 Smithsonian Astrophysical Observatory
 
 This software is released under the GNU General Public License.  You
 may find a copy at
