@@ -84,22 +84,22 @@ has template => (
 [% END -%]
 [%- FOREACH cmd IN pipe.cmds.elements %]
 [%- IF cmd.first %]  [% ELSE %]\t\\
-| [% END %][% color.cmd.cmd %][% cmd.quoted_cmd %][% color.reset %]
+| [% END %][% color.cmd.cmd %][% cmd.cmd %][% color.reset %]
 [%- FOREACH arg IN cmd.args.elements %]\t\\
     [% color.cmd.arg.pfx %][% arg.pfx %]
-[%- color.cmd.arg.name %][% arg.quoted_name %]
+[%- color.cmd.arg.name %][% arg.name %]
 [%- IF arg.has_value %][%- IF arg.sep %][% color.cmd.arg.sep %][% arg.sep %][% ELSE %] [% END %]
-[%- color.cmd.arg.value %][% arg.quoted_value %][% END %][% color.reset %]
+[%- color.cmd.arg.value %][% IF arg.has_blank_value%]''[% ELSE %][% arg.value %][% END %][% END %][% color.reset %]
 [%- END %]
 [%- FOREACH stream IN cmd.streams.elements %]\t\\
 [% color.cmd.stream.spec %][% stream.spec %]
-[%- IF stream.has_file %] [% END %][% color.cmd.stream.file %][% stream.quoted_file %][% color.reset %]
+[%- IF stream.file %] [% END %][% color.cmd.stream.file %][% stream.file %][% color.reset %]
 [%- END %]
 [%- END %]
 [%- IF pipe.streams.empty %][% ELSE %]\t\\
 )[% FOREACH stream IN pipe.streams.elements %]\t\\
 [% color.pipe.stream.spec %][% stream.spec -%]
-[%- IF stream.has_file %] [% END %][% color.pipe.stream.file %][% stream.quoted_file %][% color.reset %]
+[%- IF stream.file %] [% END %][% color.pipe.stream.file %][% stream.file %][% color.reset %]
 [%- END %]
 [%- END %]
 EOT
@@ -178,7 +178,7 @@ __END__
 
 =head1 NAME
 
-B<IPC::PrettyPipe::Render::Template::Tiny> - rendering backend using B<Template::Tiny>
+B<IPC::PrettyPipe::Render::Template::Tiny> - rendering backend using B<L<Template::Tiny>>
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ stored as a hashref with the following default contents:
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2014 Smithsonian Astrophysical Observatory
+Copyright 2013 Smithsonian Astrophysical Observatory
 
 This software is released under the GNU General Public License.  You
 may find a copy at
